search.paths.ind: Searches for individual-level paths. Ties together...

View source: R/search.paths.ind.R

search.paths.indR Documentation

Searches for individual-level paths. Ties together highest.mi, return.mis, prune, and get.params functions.

Description

Searches for individual-level paths. Ties together highest.mi, return.mis, prune, and get.params functions.

Usage

search.paths.ind(
  dat,
  k,
  data_list,
  base_syntax,
  fixed_syntax,
  elig_paths,
  prop_cutoff,
  n_subj,
  chisq_cutoff,
  stop_crit = "standard",
  subgroup_stage,
  hybrid,
  dir_prop_cutoff,
  ind_z_cutoff,
  rmsea_cutoff = 0.05,
  srmr_cutoff = 0.05,
  nnfi_cutoff = 0.95,
  cfi_cutoff = 0.95,
  n_excellent = 2,
  alpha = 0.05,
  indiv_correct = "Bonferroni"
)

Arguments

dat

Object created at beginning of gimme containing static info.

k

Which individual this is.

data_list

A list of datasets to be used in a given stage of the search. Varies based on group, subgroup, or individual-level stage.

base_syntax

A character vector containing syntax that never changes.

fixed_syntax

A character vector containing syntax that does not change in a given stage of searching.

elig_paths

A character vector containing eligible paths that gimme is allowed to add to the model at a given stage.

prop_cutoff

The proportion of individuals for whom a path must be nonsignificant in order for it to be dropped from the models. NULL if used at the individual-level.

n_subj

The number of subjects in a given stage of the search. If in the group stage, n_subj equals the number of subjects. If in the subgroup stage, n_subj equals the number of individuals in a given subgroup. At the individual stage, n_subj = 1.

chisq_cutoff

Cutoff used in order for MI to be considered significant. Value varies depending on stage of search (e.g., group, subgroup, individual).

stop_crit

Stopping criterion for the individual-level search.

subgroup_stage

Logical. Only present in order to instruct gimme what message to print to console using writeLines.

rmsea_cutoff

Cutoff for RMSEA for an individual model(default is .05; must be between 0.0 and 1.0).

srmr_cutoff

Cutoff for SRMR for an individual model (default is .05; must be between 0.0 and 1.0).

nnfi_cutoff

Cutoff for NNFI for an individual model (default is .95; must be between 0.0 and 1.0).

cfi_cutoff

Cutoff for CFI for an individual model (default is .95; must be between 0.0 and 1.0).

n_excellent

Number of fit indices needed to surpass their cutoffs for an individual model to be considered excellent. Default is 2. Max is 4.

alpha

Alpha level for significance testing. Default is .05.

Value

Returns updated values of n_paths and add_syntax.


gimme documentation built on April 17, 2026, 5:07 p.m.