Searches for individual-level paths. Ties together highest.mi, return.mis, prune, and get.params functions.
search.paths.ind(
dat,
k,
data_list,
base_syntax,
fixed_syntax,
elig_paths,
prop_cutoff,
n_subj,
chisq_cutoff,
stop_crit = "standard",
subgroup_stage,
hybrid,
dir_prop_cutoff,
ind_z_cutoff,
rmsea_cutoff = 0.05,
srmr_cutoff = 0.05,
nnfi_cutoff = 0.95,
cfi_cutoff = 0.95,
n_excellent = 2
)Returns updated values of n_paths and add_syntax.
Object created at beginning of gimme containing static info.
Which individual this is.
A list of datasets to be used in a given stage of the search. Varies based on group, subgroup, or individual-level stage.
A character vector containing syntax that never changes.
A character vector containing syntax that does not change in a given stage of searching.
A character vector containing eligible paths that gimme is allowed to add to the model at a given stage.
The proportion of individuals for whom a path must be nonsignificant in order for it to be dropped from the models. NULL if used at the individual-level.
The number of subjects in a given stage of the search. If in the group stage, n_subj equals the number of subjects. If in the subgroup stage, n_subj equals the number of individuals in a given subgroup. At the individual stage, n_subj = 1.
Cutoff used in order for MI to be considered significant. Value varies depending on stage of search (e.g., group, subgroup, individual).
Stopping criterion for the individual-level search.
Logical. Only present in order to instruct gimme what message to print to console using writeLines.
Cutoff for RMSEA for an individual model(default is .05; must be between 0.0 and 1.0).
Cutoff for SRMR for an individual model (default is .05; must be between 0.0 and 1.0).
Cutoff for NNFI for an individual model (default is .95; must be between 0.0 and 1.0).
Cutoff for CFI for an individual model (default is .95; must be between 0.0 and 1.0).
Number of fit indices needed to surpass their cutoffs for an individual model to be considered excellent. Default is 2. Max is 4.